#!/usr/bin/sh
#
# 	Part of kde-service-menu-pdf Version 0.6
# 	Copyright (C) 2014 Giuseppe Benigno <giuseppe.benigno(at)gmail.com>
#
# 	This program is free software: you can redistribute it and/or modify
# 	it under the terms of the GNU General Public License as published by
# 	the Free Software Foundation, either version 3 of the License, or
# 	(at your option) any later version.
#
# 	This program is distributed in the hope that it will be useful,
# 	but WITHOUT ANY WARRANTY; without even the implied warranty of
# 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# 	GNU General Public License for more details.
#
# 	You should have received a copy of the GNU General Public License
# 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

lang=`echo "${1}" | sed -e "s/@//g"`
shift
action="${1}"
shift

#### languages strings messages #################
# Syntax for strings name is: msg_[$action]_$window_[$section]
# For languages as sr@Latn use srLatn

load_language_en () {
	msg_png_dpi_title="Document resolution"
	msg_png_dpi_text="Please write DPI resolution for the document. Right range values is from 75 to 6000. Default is 300 DPI."

	msg_options_title="Advanced options"
	msg_options_text="Advanced options"
	msg_options_Monochrome="Render as monochrome bitmaps."
	msg_options_noMetadata="Don´t extract the metadata."
	msg_options_noHyperlinks="Don´t extract hyperlinks."
	msg_alert_overwrite_title="Overwrite all?"
	msg_alert_overwrite_text="One or more destination files exist! Overwrite all?"
	msg_saveFile_title="Save document"

	msg_convert_finish_title="Conversion to djvu file"
	msg_convert_finish_text="Conversion of document \"${baseFileName}\" ... done"
}

load_language_it () {
	msg_png_dpi_title="Risoluzione"
	msg_png_dpi_text="Pre favore scrivi la risoluzione voluta per il documento finale. Valori validi sono compresi tra 75 e 6000. 300 DPI è il valore predefinito."

	msg_options_title="Opzioni avanzate"
	msg_options_text="Opzioni avanzate"
	msg_options_Monochrome="Renderizza come immagini monocromatiche"
	msg_options_noMetadata="Non estrarre i metadati."
	msg_options_noHyperlinks="Non estrarre i collegamenti ipertestuali."
	msg_alert_overwrite_title="Sovrascrivi tutti?"
	msg_alert_overwrite_text="Uno o più file destinazione esistono già! Sovrascriverli tutti?"
	msg_saveFile_title="Salva documento"

	msg_convert_finish_title="Conversione a file djvu"
	msg_convert_finish_text="Conversione del documento \"${baseFileName}\" ... conclusa"
}

load_language_ru () {
	msg_png_dpi_title="Разрешение документа"
	msg_png_dpi_text="Пожалуйста, напишите DPI разрешение для документа. Правильный диапазон значений от 75 до 6000. По умолчанию 300 DPI."

	msg_options_title="Дополнительные настройки"
	msg_options_text="Дополнительные настройки"
	msg_options_Monochrome="Рендер как монохромные растровые изображения."
	msg_options_noMetadata="Не извлекать метаданные."
	msg_options_noHyperlinks="Не извлекать гиперссылки."
	msg_alert_overwrite_title="Перезаписать все?"
	msg_alert_overwrite_text="Один или несколько файлов назначения существуют! Перезаписать все?"
	msg_saveFile_title="Сохранить документ"

	msg_convert_finish_title="Преобразование в djvu файл"
	msg_convert_finish_text="Преобразование в документ \"${baseFileName}\" ... сделано"
}

################################################

dpi300 () {
	dpi=300
	options=" "
	advanced "${@}"
}

dpi600 () {
	dpi=600
	options=" "
	advanced "${@}"
}

dpi () {
	options=" "
	advanced "${@}"
}

advanced () {
	while [ $# -ne 0 ]; do
		## Input files must have absolute path!
		workDir="${1%/*}"; [ ! -d "${workDir}" ] && workDir="./"
		fileName="${1##*/}"
		baseFileName="${fileName%.*}"
		"load_language_${lang}" || load_language_en

		# only first time
		[ ! "$dpi" ] && { dpi=`kdialog --title "${msg_png_dpi_title}" --caption "${msg_png_dpi_title}" --icon configure --inputbox "${msg_png_dpi_text}" "300"` || exit; }

		# only first time
		if [ ! "$options" ]; then
			options=`kdialog --title "${msg_options_title}" --caption "${msg_options_title}" --icon configure --checklist "${msg_options_text}" __monochrome "${msg_options_Monochrome}" off __no-metadata "${msg_options_noMetadata}" off __no-hyperlinks "${msg_options_noHyperlinks}" off --separate-output` || exit
			options=`echo ${options} | sed 'y/_/-/'`
		fi

		cd "${workDir}"
			outputFileName="${baseFileName}.djvu"
			if [ -e "${outputFileName}" ]; then
				if [ "$multiSelection" ];
					then	if [ ! "$overwriteAll" ];				# if $overwriteAll is unset
								then	kdialog --title "${msg_alert_overwrite_title}" --caption "${msg_alert_overwrite_title}" --icon document-save-all --yesnocancel "${msg_alert_overwrite_text}"
										case "$?" in
											0)	overwriteAll="true";;		# click on Yes
											1)	overwriteAll="false";;		# click on No
											2)	exit;;						# click on Cancel
										esac
							fi
							[ "$overwriteAll" = "false" ] && outputFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}.djvu" image/vnd.djvu` || exit
					else	outputFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}.djvu" image/vnd.djvu` || exit
				fi
			fi
			pdf2djvu -o "${outputFileName}" --dpi="${dpi}" ${options} "${1}" && kdialog --title "${msg_convert_finish_title}" --passivepopup "${msg_convert_finish_text}" 5
		cd -
		shift
	done
}

#### main

if [ $# -gt 1 ];
	then multiSelection="true"
	else unset multiSelection
fi
"${action}" "${@}"
