#!/usr/bin/sh
#
# 	Part of kde-service-menu-pdf Version 0.6
# 	Copyright (C) 2014 Giuseppe Benigno <giuseppe.benigno(at)gmail.com>
#
# 	This program is free software: you can redistribute it and/or modify
# 	it under the terms of the GNU General Public License as published by
# 	the Free Software Foundation, either version 3 of the License, or
# 	(at your option) any later version.
#
# 	This program is distributed in the hope that it will be useful,
# 	but WITHOUT ANY WARRANTY; without even the implied warranty of
# 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# 	GNU General Public License for more details.
#
# 	You should have received a copy of the GNU General Public License
# 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

lang=`echo "${1}" | sed -e "s/@//g"`
shift
action="${1}"
shift
workDir="${1%/*}"; if [ ! -d "${workDir}" ]; then workDir="./"; fi
baseFileName=`echo "${@}" | sed -e "s/ \//\n\//g" | sed -e "s/ /\ /g" | sed -e "s/.*\// /" | sed -e "s/[.]pdf$//" | tr "\n" "," | sed -e "s/^ \(.*\),[[:blank:]]*$/\1/"`

#### languages strings messages #################
# Syntax for strings name is: msg_[$action]_$window_[$section]
# For languages as sr@Latn use srLatn

load_language_en () {
	msg_print_FileMissing="Please select at least one file."
	msg_print_choose_printer="Choose Printer:"
	msg_print_finish_title="Printed documents \"${baseFileName}\""
	msg_print_finish="Done."
}

load_language_it () {
	msg_print_FileMissing="Per favore, seleziona almeno un file."
	msg_print_choose_printer="Seleziona la stampante:"
	msg_print_finish_title="Documenti mandati in stampa: \"${baseFileName}\""
	msg_print_finish="Finito."
}

load_language_de () {
	msg_print_FileMissing="Bitte mindestens eine Datei auswählen."
	msg_print_choose_printer="Wählen Sie Drucker"
	msg_print_finish_title="Dateien gedruckt\"${baseFileName}\""
	msg_print_finish="Fertig."
}

load_language_ru () {
	msg_print_FileMissing="Пожалуйста, выберите хотя бы один файл."
	msg_print_choose_printer="Выберите принтер:"
	msg_print_finish_title="Печатаемые документы \"${baseFileName}\""
	msg_print_finish="Готово."
}

################################################

print () {
	if [ ${#} -lt 1 ]; then
		kdialog -sorry "${msg_print_FileMissing}"
		exit
	fi
	# build printer list
	printer_default=`lpstat -p -d | grep default | cut -f2 -d':'`
	printers=`lpstat -a | cut -f1 -d' '`
	pp=''
	for printer in $printers
	do
		#echo "$pp $printer $printer"
		pp=`echo "$pp $printer $printer"`
		[ x"${printer}" = x"${printer_default}" ] && pp=`echo $pp on` || pp=`echo $pp off`
		#echo $pp
	done

	printer="`kdialog --radiolist "${msg_print_choose_printer}" $pp` "

	for f in "${@}";do
		lpr -P ${printer} "$f"
	done && \
	kdialog --title "${msg_print_finish_title} " --passivepopup "${msg_print_finish}" 5
}

#### main

cd "${workDir}"
	"load_language_${lang}" || load_language_en
	"${action}" "${@}"
cd -
