#!/usr/bin/sh
#
# 	Part of kde-service-menu-pdf Version 0.6
# 	Copyright (C) 2014 Giuseppe Benigno <giuseppe.benigno(at)gmail.com>
#
# 	This program is free software: you can redistribute it and/or modify
# 	it under the terms of the GNU General Public License as published by
# 	the Free Software Foundation, either version 3 of the License, or
# 	(at your option) any later version.
#
# 	This program is distributed in the hope that it will be useful,
# 	but WITHOUT ANY WARRANTY; without even the implied warranty of
# 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# 	GNU General Public License for more details.
#
# 	You should have received a copy of the GNU General Public License
# 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

lang=`echo "${1}" | sed -e "s/@//g"`
shift
action="${1}"
shift
workDir="${1%/*}"; if [ ! -d "${workDir}" ]; then workDir="./"; fi
fileName="${1##*/}"
baseFileName="${fileName%.*}"

#### languages strings messages #################
# Syntax for strings name is: msg_[$action]_$window_[$section]
# For languages as sr@Latn use srLatn

load_language_en () {
	msg_insertPasswd_title="Insert password"
	msg_insertPasswd_usr="Please insert user password of document \"${baseFileName}\":"
	msg_insertPasswd_own="Please insert main password of document \"${baseFileName}\":"

	msg_inputPagesRange_title="Input pages range"
	msg_inputPagesRange="Notes: The keyword \"end\" may be used to reference the final page of a document instead of a page number. Please input page range to convert from \"${baseFileName}\":"

	msg_options_title="Preferences"
	msg_options="Select options for conversion of \"${baseFileName}\""
	msg_options_layout="Maintain the  original physical layout"
	msg_options_html="Generate a simple HTML file"
	msg_options_NoBreaks="Don’t insert page breaks (all in one page)"

	msg_saveFile_title="Save document"

	msg_finish_title="Conversion of all pages the document \"${baseFileName}\""
	msg_selected_finish_title="Conversion of selected pages of document \"${baseFileName}\""
	msg_finish="Done."
}

load_language_it () {
	msg_insertPasswd_title="Inserisci Password"
	msg_insertPasswd_usr="Per favore digita la password utente di \"${baseFileName}\":"
	msg_insertPasswd_own="Per favore digita la password principale di \"${baseFileName}\":"

	msg_inputPagesRange_title="Selezione range:"
	msg_inputPagesRange="Nota: La parola chiave \"end\" può essere usata per indicare la pagina finale di un documento al posto di un valore numerico. Per favore inserisci il range di pagine da convertire in testo da \"${baseFileName}\":"

	msg_options_title="Preferenze"
	msg_options="Seleziona le opzioni per la conversione di \"${baseFileName}\""
	msg_options_layout="Mantiene aspetto originale"
	msg_options_html="Genera un file html semplice"
	msg_options_NoBreaks="Non inserisce interruzioni di pagina (all in one page)"

	msg_saveFile_title="Salva documento"

	msg_finish_title="Conversione di tutte le pagine del documento \"${baseFileName}\""
	msg_selected_finish_title="Conversione delle pagine selezionate del documento \"${baseFileName}\""
	msg_finish="Conclusa."
}

load_language_de () {
	msg_insertPasswd_title="Passwort eingeben"
	msg_insertPasswd_usr="Bitte das Benutzerpasswort für \"${baseFileName}\" eingeben:"
	msg_insertPasswd_own="Bitte das Masterpasswort für \"${baseFileName}\" eingeben:"

	msg_inputPagesRange_title="Seitenbereich eingeben"
	msg_inputPagesRange="Beachte: Das Schlüsselwort \"end\" kann für die letzte Seite benutzt werden, anstatt deren Seitenzahl anzugeben. Bitte Seitenbereich von \"${baseFileName}\" angeben, der umgewandelt werden soll:"

	msg_options_title="Eigenschaften"
	msg_options="Optionen für die Umwandlung von \"${baseFileName}\" auswählen"
	msg_options_layout="Urprüngliches Seitenlayout beibehalten"
	msg_options_html="Eine einfache HTML-Datei erzeugen"
	msg_options_NoBreaks="Keine Seitenumbrüche erstellen (Alles auf einer Seite)"

	msg_saveFile_title="Dokument speichern"

	msg_finish_title="Umwandlung aller Seiten von \"${baseFileName}\""
	msg_selected_finish_title="Umwandlung ausgewählter Seiten von \"${baseFileName}\""
	msg_finish="Fertig."
}

load_language_ru () {
	msg_insertPasswd_title="Вставить пароль"
	msg_insertPasswd_usr="Пожалуйста, вставьте пароль пользователя для документа \"${baseFileName}\":"
	msg_insertPasswd_own="Пожалуйста, вставьте основной пароль для документа \"${baseFileName}\":"

	msg_inputPagesRange_title="Выбрать диапазон страниц"
	msg_inputPagesRange="Примечание: Ключевое слово \"end\" может использоваться, чтобы сослаться на заключительную страницу документа вместо номера страницы. Пожалуйста, вставьте диапазон страниц для преобразования из \"${baseFileName}\":"

	msg_options_title="Параметры"
	msg_options="Выбор параметров для конвертации \"${baseFileName}\""
	msg_options_layout="Сохранять исходное расположение"
	msg_options_html="Создать простой HTML файл"
	msg_options_NoBreaks="Не вставлять разрывы страниц (все на одной странице)"

	msg_saveFile_title="Сохранить документ"

	msg_finish_title="Преобразование всех страниц документа \"${baseFileName}\""
	msg_selected_finish_title="Преобразование выбранных страниц документа \"${baseFileName}\""
	msg_finish="Готово."
}

################################################

all () {
	options=`kdialog --title "${msg_options_title}" --caption "${msg_options_title}" --icon configure --checklist "${msg_options}" _layout "${msg_options_layout}" on _htmlmeta "${msg_options_html}" off _nopgbrk "${msg_options_NoBreaks}" off --separate-output` || exit
	options=`echo ${options} | sed 'y/_/-/'`
	txtFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}" text/plain` || exit
	pdftotext ${options} "${@}" "${txtFileName}" && \
	kdialog --title "${msg_finish_title}" --passivepopup "${msg_finish}" 5
}

all_usr () {
	usr_passwd=`kdialog --title "${msg_insertPasswd_title}" --caption "${msg_insertPasswd_title}" --password "${msg_insertPasswd_usr}"` || exit
	usr_passwd=`echo ${usr_passwd} |grep '^.' |sed 's/^/-upw /'`
	options=`kdialog --title "${msg_options_title}" --caption "${msg_options_title}" --icon configure --checklist "${msg_options}" _layout "${msg_options_layout}" on _htmlmeta "${msg_options_html}" off _nopgbrk "${msg_options_NoBreaks}" off --separate-output` || exit
	options=`echo ${options} | sed 'y/_/-/'`
	txtFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}" text/plain` || exit
	pdftotext "${usr_passwd}" ${options} "${@}" "${txtFileName}" && \
	kdialog --title "${msg_finish_title}" --passivepopup "${msg_finish}" 5
}

all_own () {
	own_passwd=`kdialog --title "${msg_insertPasswd_title}" --caption "${msg_insertPasswd_title}" --password "${msg_insertPasswd_own}"` || exit
	own_passwd=`echo ${own_passwd} |grep '^.' |sed 's/^/-opw /'`
	options=`kdialog --title "${msg_options_title}" --caption "${msg_options_title}" --icon configure --checklist "${msg_options}" _layout "${msg_options_layout}" on _htmlmeta "${msg_options_html}" off _nopgbrk "${msg_options_NoBreaks}" off --separate-output` || exit
	options=`echo ${options} | sed 'y/_/-/'`
	txtFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}" text/plain` || exit
	pdftotext "${own_passwd}" ${options} "${@}" "${txtFileName}" && \
	kdialog --title "${msg_finish_title}" --passivepopup "${msg_finish}" 5
}

selected () {
	range=`kdialog --title "${msg_inputPagesRange_title}" --caption "${msg_inputPagesRange_title}" --icon edit-copy --inputbox "${msg_inputPagesRange}" "1-end"` || exit
	range=`echo "${range}" | sed 's/[[:blank:]]*//g' | sed 's/-end//' | sed 's/\(^[0-9][0-9]*\)/-f \1/' | sed 's/\(^-f [0-9][0-9]*\)-\([0-9][0-9]*\)/\1 -l \2/'| sed 's/^-\([0-9][0-9]*\)/-l \1/'`
	options=`kdialog --title "${msg_options_title}" --caption "${msg_options_title}" --icon configure --checklist "${msg_options}" _layout "${msg_options_layout}" on _htmlmeta "${msg_options_html}" off _nopgbrk "${msg_options_NoBreaks}" off --separate-output` || exit
	options=`echo ${options} | sed 'y/_/-/'`
	txtFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}" text/plain` || exit
	pdftotext ${options} ${range} "${@}" "${txtFileName}" && \
	kdialog --title "${msg_selected_finish_title}" --passivepopup "${msg_finish}" 5
}

selected_usr () {
	usr_passwd=`kdialog --title "${msg_insertPasswd_title}" --caption "${msg_insertPasswd_title}" --password "${msg_insertPasswd_usr}"` || exit
	usr_passwd=`echo ${usr_passwd} |grep '^.' |sed 's/^/-upw /'`
	range=`kdialog --title "${msg_inputPagesRange_title}" --caption "${msg_inputPagesRange_title}" --icon edit-copy --inputbox "${msg_inputPagesRange}" "1-end"` || exit
	range=`echo "${range}" | sed 's/[[:blank:]]*//g' | sed 's/-end//' | sed 's/\(^[0-9][0-9]*\)/-f \1/' | sed 's/\(^-f [0-9][0-9]*\)-\([0-9][0-9]*\)/\1 -l \2/'| sed 's/^-\([0-9][0-9]*\)/-l \1/'`
	options=`kdialog --title "${msg_options_title}" --caption "${msg_options_title}" --icon configure --checklist "${msg_options}" _layout "${msg_options_layout}" on _htmlmeta "${msg_options_html}" off _nopgbrk "${msg_options_NoBreaks}" off --separate-output` || exit
	options=`echo ${options} | sed 'y/_/-/'`
	txtFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}" text/plain` || exit
	pdftotext "${usr_passwd}" ${options} ${range} "${@}" "${txtFileName}" && \
	kdialog --title "${msg_selected_finish_title}" --passivepopup "${msg_finish}" 5
}

selected_own () {
	own_passwd=`kdialog --title "${msg_insertPasswd_title}" --caption "${msg_insertPasswd_title}" --password "${msg_insertPasswd_own}"` || exit
	own_passwd=`echo ${own_passwd} |grep '^.' |sed 's/^/-opw /'`
	range=`kdialog --title "${msg_inputPagesRange_title}" --caption "${msg_inputPagesRange_title}" --icon edit-copy --inputbox "${msg_inputPagesRange}" "1-end"` || exit
	range=`echo "${range}" | sed 's/[[:blank:]]*//g' | sed 's/-end//' | sed 's/\(^[0-9][0-9]*\)/-f \1/' | sed 's/\(^-f [0-9][0-9]*\)-\([0-9][0-9]*\)/\1 -l \2/'| sed 's/^-\([0-9][0-9]*\)/-l \1/'`
	options=`kdialog --title "${msg_options_title}" --caption "${msg_options_title}" --icon configure --checklist "${msg_options}" _layout "${msg_options_layout}" on _htmlmeta "${msg_options_html}" off _nopgbrk "${msg_options_NoBreaks}" off --separate-output` || exit
	options=`echo ${options} | sed 'y/_/-/'`
	txtFileName=`kdialog --title "${msg_saveFile_title}" --caption "${msg_saveFile_title}" --icon document-save --getsavefilename "${workDir}/${baseFileName}" text/plain` || exit
	pdftotext "${own_passwd}" ${options} ${range} "${@}" "${txtFileName}" && \
	kdialog --title "${msg_selected_finish_title}" --passivepopup "${msg_finish}" 5
}

#### main

cd "${workDir}"
    "load_language_${lang}" || load_language_en
	"${action}" "${@}"
cd -
